@@ -21,6 +21,7 @@
 use crate::{
     config::{VectorConfig, VectorType},
     segment::Elem,
+    vector_types::rabitq,
 };
 use memmap2::Mmap;
 use node::Node;
@@ -42,33 +43,44 @@ pub struct DataStoreV1 {
 }
 
 impl DataStore for DataStoreV1 {
+    fn has_quantized(&self) -> bool {
+        false
+    }
+
     fn size_bytes(&self) -> usize {
         self.nodes.len()
     }
 
-    fn stored_paragraph_count(&self) -> usize {
-        store::stored_elements(&self.nodes)
+    fn stored_paragraph_count(&self) -> u32 {
+        store::stored_elements(&self.nodes) as u32
     }
 
-    fn stored_vector_count(&self) -> usize {
+    fn stored_vector_count(&self) -> u32 {
         self.stored_paragraph_count()
     }
 
-    fn get_vector(&self, VectorAddr(id): VectorAddr) -> VectorRef {
+    fn get_vector(&self, VectorAddr(id): VectorAddr) -> VectorRef<'_> {
         VectorRef {
             vector: store::get_value(&self.nodes, id as usize).vector(),
             paragraph_addr: ParagraphAddr(id),
         }
     }
 
+    fn get_quantized_vector(&self, _id: VectorAddr) -> rabitq::EncodedVector<'_> {
+        panic!("Store does not have quantized vectors")
+    }
+
     fn will_need(&self, id: VectorAddr) {
         store::will_need(&self.nodes, id.0 as usize, self.vector_len_bytes);
     }
+
+    fn will_need_quantized(&self, _id: VectorAddr) {}
+
     fn as_any(&self) -> &dyn Any {
         self
     }
 
-    fn get_paragraph(&self, ParagraphAddr(id): ParagraphAddr) -> ParagraphRef {
+    fn get_paragraph(&self, ParagraphAddr(id): ParagraphAddr) -> ParagraphRef<'_> {
         ParagraphRef::V1(store::get_value(&self.nodes, id as usize))
     }
 }
